@@ -42,8 +42,8 @@ class BPLINK2PLINK(ConvBase):
             bioconvert bplink2plink plink_toy
 
         Since there is no extension, you must be explicit by providing the
-        conversion name (bplink2plink). This command will search for 3 input 
-        files plink_toy.bed, plink_toy.bim and plink_toy.fam. It will then 
+        conversion name (bplink2plink). This command will search for 3 input
+        files plink_toy.bed, plink_toy.bim and plink_toy.fam. It will then
         create two output files named plink_toy.ped and plink_toy.map
 
     """
@@ -66,7 +66,5 @@ class BPLINK2PLINK(ConvBase):
         """Convert plink file in text using plink executable.
 
         `plink documentation <http://hpc.ilri.cgiar.org/beca/training/data_mgt_2017/BackgroundMaterial/PlinkTutorial.pdf>`_"""
-        cmd = "plink --bfile {infile} --recode --out {outfile}".format(
-            infile=self.infile, outfile=self.outfile
-        )
+        cmd = "plink --bfile {infile} --recode --out {outfile}".format(infile=self.infile, outfile=self.outfile)
         self.execute(cmd)
