@@ -82,11 +82,7 @@ def compressor(func):
             (_, base_suffix) = splitext(ungz_name)
             with TempFile(suffix=base_suffix) as ungz_infile:
                 inst.infile = ungz_infile.name
-                inst.shell(
-                    "unpigz -c -p {} {} > {}".format(
-                        inst.threads, infile_name, inst.infile
-                    )
-                )
+                inst.shell("unpigz -c -p {} {} > {}".format(inst.threads, infile_name, inst.infile))
                 # computation
                 results = func(inst, *args, **kwargs)
             inst.infile = infile_name
@@ -105,11 +101,7 @@ def compressor(func):
             inst.outfile = inst.outfile + ".bz2"
         elif output_compressed == ".dsrc":  # !!! only for FastQ files
             _log.info("Compressing output into .dsrc")
-            inst.shell(
-                "dsrc c -t{} {} {}.dsrc".format(
-                    inst.threads, inst.outfile, inst.outfile
-                )
-            )
+            inst.shell("dsrc c -t{} {} {}.dsrc".format(inst.threads, inst.outfile, inst.outfile))
             inst.outfile = inst.outfile + ".dsrc"
         return results
 
@@ -149,11 +141,7 @@ def out_compressor(func):
             inst.outfile = inst.outfile + ".bz2"
         elif output_compressed == ".dsrc":  # !!! only for FastQ files
             _log.info("Compressing output into .dsrc")
-            inst.shell(
-                "dsrc c -t{} {} {}.dsrc".format(
-                    inst.threads, inst.outfile, inst.outfile
-                )
-            )
+            inst.shell("dsrc c -t{} {} {}.dsrc".format(inst.threads, inst.outfile, inst.outfile))
             inst.outfile = inst.outfile + ".dsrc"
         return results
 
@@ -235,15 +223,32 @@ def get_known_dependencies_with_availability(as_dict=False):
         external_binaries = {}
         python_libraries = {}
         for binary, missing in getattr(requires, "__missing_binaries", {}).items():
-            external_binaries[binary] = dict(available=not missing,)
+            external_binaries[binary] = dict(
+                available=not missing,
+            )
         for library, missing in getattr(requires, "__missing_libraries", {}).items():
-            python_libraries[library] = dict(available=not missing,)
+            python_libraries[library] = dict(
+                available=not missing,
+            )
         return dict(
-            external_binaries=external_binaries, python_libraries=python_libraries,
+            external_binaries=external_binaries,
+            python_libraries=python_libraries,
         )
     ret = []
     for binary, status in sorted(getattr(requires, "__missing_binaries", {}).items()):
-        ret.append((binary, not status, "binary",))
+        ret.append(
+            (
+                binary,
+                not status,
+                "binary",
+            )
+        )
     for library, status in sorted(getattr(requires, "__missing_libraries", {}).items()):
-        ret.append((library, not status, "library",))
+        ret.append(
+            (
+                library,
+                not status,
+                "library",
+            )
+        )
     return ret
