@@ -34,7 +34,7 @@ import subprocess as sp
 
 import colorlog
 
-_log = colorlog.getLogger(__name__)
+logger = colorlog.getLogger(__name__)
 
 
 STDOUT = sys.stdout
@@ -67,16 +67,20 @@ class shell:
 
         close_fds = sys.platform != "win32"
 
-        _log.debug(cmd)
+        logger.debug(cmd)
         proc = sp.Popen(
             "{} {} {}".format(cls._process_prefix, cmd.rstrip(), cls._process_suffix),
             bufsize=-1,
             shell=True,
             stdout=stdout,
             close_fds=close_fds,
-            **cls._process_args
+            **cls._process_args,
         )
 
+        #import psutil
+        #pp = psutil.Process(proc.pid)
+        #logger.info(f"{pp.memory_info()}")
+
         ret = None
         if iterable:
             return cls.iter_stdout(proc, cmd)
