@@ -22,13 +22,12 @@
 ###########################################################################
 """Convert :term:`CSV` format to :term:`TSV` format"""
 import csv
+
 import colorlog
 
-from bioconvert.core.base import ConvArg
-from bioconvert.core.decorators import requires, requires_nothing
-from bioconvert.core.decorators import compressor, in_gz
-from bioconvert.core.base import ConvBase
-
+from bioconvert.core.base import ConvArg, ConvBase
+from bioconvert.core.decorators import (compressor, in_gz, requires,
+                                        requires_nothing)
 
 logger = colorlog.getLogger(__name__)
 
@@ -60,20 +59,13 @@ class CSV2TSV(ConvBase):
     @requires_nothing
     @compressor
     def _method_python(
-        self,
-        in_sep=DEFAULT_IN_SEP,
-        out_sep=DEFAULT_OUT_SEP,
-        line_terminator=DEFAULT_LINE_TERMINATOR,
-        *args,
-        **kwargs
+        self, in_sep=DEFAULT_IN_SEP, out_sep=DEFAULT_OUT_SEP, line_terminator=DEFAULT_LINE_TERMINATOR, *args, **kwargs
     ):
         """Do the conversion :term:`CSV` -> :term:`TSV` using standard Python modules.
 
         `csv documentation <https://docs.python.org/3/library/csv.html>`_"""
         with open(self.infile, "r") as in_stream, open(self.outfile, "w") as out_stream:
-            writer = csv.writer(
-                out_stream, delimiter=out_sep, lineterminator=line_terminator
-            )
+            writer = csv.writer(out_stream, delimiter=out_sep, lineterminator=line_terminator)
             reader = csv.reader(in_stream, delimiter=in_sep)
             for row in reader:
                 writer.writerow(row)
@@ -81,17 +73,12 @@ class CSV2TSV(ConvBase):
     @requires_nothing
     @compressor
     def _method_python_v2(
-        self,
-        in_sep=DEFAULT_IN_SEP,
-        out_sep=DEFAULT_OUT_SEP,
-        line_terminator=DEFAULT_LINE_TERMINATOR,
-        *args,
-        **kwargs
+        self, in_sep=DEFAULT_IN_SEP, out_sep=DEFAULT_OUT_SEP, line_terminator=DEFAULT_LINE_TERMINATOR, *args, **kwargs
     ):
         """Do the conversion :term:`CSV` -> :term:`CSV` using csv module.
 
         .. note:: This method cannot escape nor quote output char
-        
+
         `csv documentation <https://docs.python.org/3/library/csv.html>`_"""
         with open(self.infile, "r") as in_stream, open(self.outfile, "w") as out_stream:
             reader = csv.reader(in_stream, delimiter=in_sep)
@@ -102,16 +89,11 @@ class CSV2TSV(ConvBase):
     @requires(python_library="pandas")
     @compressor
     def _method_pandas(
-        self,
-        in_sep=DEFAULT_IN_SEP,
-        out_sep=DEFAULT_OUT_SEP,
-        line_terminator=DEFAULT_LINE_TERMINATOR,
-        *args,
-        **kwargs
+        self, in_sep=DEFAULT_IN_SEP, out_sep=DEFAULT_OUT_SEP, line_terminator=DEFAULT_LINE_TERMINATOR, *args, **kwargs
     ):
         """Do the conversion :term:`CSV` -> :term:`TSV` using Pandas library
-        
-        
+
+
         `pandas documentation <https://pandas.pydata.org/docs/>`_"""
         import pandas as pd
 
@@ -126,17 +108,23 @@ class CSV2TSV(ConvBase):
     @classmethod
     def get_additional_arguments(cls):
         yield ConvArg(
-            names=["--in-sep",],
+            names=[
+                "--in-sep",
+            ],
             default=cls.DEFAULT_IN_SEP,
             help="The separator used in the input file",
         )
         yield ConvArg(
-            names=["--out-sep",],
+            names=[
+                "--out-sep",
+            ],
             default=cls.DEFAULT_OUT_SEP,
             help="The separator used in the output file",
         )
         yield ConvArg(
-            names=["--line-terminator",],
+            names=[
+                "--line-terminator",
+            ],
             default=cls.DEFAULT_LINE_TERMINATOR,
             help="The line terminator used in the output file",
         )
