@@ -22,11 +22,11 @@
 ###########################################################################
 
 """Convert :term:`SAM` file to :term:`BAM` format"""
+import colorlog
+
 from bioconvert import ConvBase
 from bioconvert.core.decorators import requires
 
-import colorlog
-
 logger = colorlog.getLogger(__name__)
 
 __all__ = ["SAM2BAM"]
@@ -50,13 +50,11 @@ class SAM2BAM(ConvBase):
 
     @requires("samtools")
     def _method_samtools(self, *args, **kwargs):
-        """ Do the conversion :term:`SAM` -> :term:`BAM` using samtools
+        """Do the conversion :term:`SAM` -> :term:`BAM` using samtools
 
         `SAMtools documentation <http://www.htslib.org/doc/samtools.html>`_"""
         # -S means ignored (input format is auto-detected)
         # -b means output to BAM format
         # -h means include header in SAM output
-        cmd = "samtools view -Sbh -@ {} {} > {}".format(
-            self.threads, self.infile, self.outfile
-        )
+        cmd = "samtools view -Sbh -@ {} {} > {}".format(self.threads, self.infile, self.outfile)
         self.execute(cmd)
