@@ -24,11 +24,10 @@
 """Convert :term:`SAM` file to :term:`CRAM` format"""
 import os
 
-from bioconvert import ConvBase
-from bioconvert.core.base import ConvArg
-
 import colorlog
 
+from bioconvert import ConvBase
+from bioconvert.core.base import ConvArg
 from bioconvert.core.decorators import requires
 
 logger = colorlog.getLogger(__name__)
@@ -40,7 +39,7 @@ class SAM2CRAM(ConvBase):
     """Convert :term:`SAM` file to :term:`CRAM` file
 
     The conversion requires the reference corresponding to the input file
-    It can be provided as an argument with the standalone (*-\\-reference*). 
+    It can be provided as an argument with the standalone (*-\\-reference*).
     Otherwise, users are asked to provide it.
 
     Methods available are based on samtools [SAMTOOLS]_.
@@ -81,9 +80,7 @@ class SAM2CRAM(ConvBase):
         if reference is None:
             reference = self._get_reference()
 
-        cmd = "samtools view -@ {} -C {} -T {} > {}".format(
-            self.threads, self.infile, reference, self.outfile
-        )
+        cmd = "samtools view -@ {} -C {} -T {} > {}".format(self.threads, self.infile, reference, self.outfile)
         try:
             self.execute(cmd)
         except:
