@@ -22,12 +22,12 @@
 ###########################################################################
 """Convert :term:`SRA` format to :term:`FASTA` format"""
 
-from bioconvert import ConvBase
-import subprocess
 import os
-import tempfile
 import shutil
+import subprocess
+import tempfile
 
+from bioconvert import ConvBase
 from bioconvert.core.decorators import requires
 
 
@@ -43,11 +43,14 @@ class SRA2FASTQ(ConvBase):
     """
 
     #: Default value
-    _default_method = "sratoolkit"
+    _default_method = "fastq_dump"
 
     # If test: will take only the first 10 reads from the sra file
     def __init__(self, infile, outfile, test=False):
-        """.. rubric:: constructorhttps://edwards.flinders.edu.au/fastq-dump/
+        """.. rubric:: constructor
+
+
+        https://edwards.flinders.edu.au/fastq-dump/
 
         library used: sra-toolkit
         """
@@ -55,7 +58,7 @@ class SRA2FASTQ(ConvBase):
         self.test = test
 
     @requires("fastq-dump")
-    def _method_sratoolkit(self, *args, **kwargs):
+    def _method_fastq_dump(self, *args, **kwargs):
         """Uses Sratoolkit (fastq-dump) to convert a sra file to fastq
 
         `Fastq-dump documentation <https://edwards.flinders.edu.au/fastq-dump/>`_"""
@@ -80,22 +83,14 @@ class SRA2FASTQ(ConvBase):
         if self.test:
             testcmd = "-X 10"
         if self.isPairedSRA(infile):
-            cmd = "fastq-dump {} {} --split-files -O {} {}".format(
-                testcmd, compresscmd, tmpdir, infile
-            )
+            cmd = "fastq-dump {} {} --split-files -O {} {}".format(testcmd, compresscmd, tmpdir, infile)
             self.execute(cmd)
-            cmd = "mv {}/{}_1.fastq{} {}_1.fastq{}".format(
-                tmpdir, inname, gzext, outbasename, gzext
-            )
+            cmd = "mv {}/{}_1.fastq{} {}_1.fastq{}".format(tmpdir, inname, gzext, outbasename, gzext)
             self.execute(cmd)
-            cmd = "mv {}/{}_2.fastq{} {}_2.fastq{}".format(
-                tmpdir, inname, gzext, outbasename, gzext
-            )
+            cmd = "mv {}/{}_2.fastq{} {}_2.fastq{}".format(tmpdir, inname, gzext, outbasename, gzext)
             self.execute(cmd)
         else:
-            cmd = "fastq-dump {} {} -O {} {}".format(
-                testcmd, compresscmd, tmpdir, infile
-            )
+            cmd = "fastq-dump {} {} -O {} {}".format(testcmd, compresscmd, tmpdir, infile)
             self.execute(cmd)
             cmd = "mv {}/{}.fastq{} {}".format(tmpdir, inname, gzext, self.outfile)
             self.execute(cmd)
@@ -103,9 +98,7 @@ class SRA2FASTQ(ConvBase):
 
     def isPairedSRA(self, filename):
         try:
-            contents = subprocess.check_output(
-                ["fastq-dump", "-X", "1", "-Z", "--split-spot", filename]
-            )
+            contents = subprocess.check_output(["fastq-dump", "-X", "1", "-Z", "--split-spot", filename])
         except subprocess.CalledProcessError:
             raise Exception("Error running fastq-dump on", filename)
 
